﻿using System;
using System.IO;
using System.Net;
using System.Web;
using System.Web.UI;
using System.Collections.Generic;
using System.Text;

using CMS.Notifications;
using CMS.GlobalHelper;
using CMS.EventLog;
using CMS.SettingsProvider;
using CMS.CMSHelper;

namespace SMSNotification
{
    /// <summary>
    /// Base class for sms notification gateway.
    /// </summary>
    public class SMSNotificationGateway : CMSNotificationGateway
    {
        #region "Public methods"

        /// <summary>
        /// Returns notification gateway form control.
        /// </summary>
        public override CMSNotificationGatewayForm GetNotificationGatewayForm()
        {
            try
            {
                Control ctrl = this.NotificationSubscriptionControl.Page.LoadControl("~/CMSModules/Notifications/Controls/NotificationSubscription/SMSNotificationSubscription.ascx");
                ctrl.ID = ValidationHelper.GetIdentificator("notif" + this.NotificationGatewayObj.GatewayName);

                return (CMSNotificationGatewayForm)ctrl;
            }
            catch (Exception ex)
            {
                try
                {
                    // Log the event
                    EventLogProvider eventLog = new EventLogProvider();
                    eventLog.LogEvent("CMSEmailNotificationGateway", "EXCEPTION", ex);
                }
                catch
                {
                    // Unable to log the event
                }
            }
            return null;
        }


        /// <summary>
        /// Send notification override for sending SMS
        /// </summary>
        public override void SendNotification()
        {
            try
            {
                if (NotificationSubscriptionObj != null)
                {
                    // Create SMS message
                    SMSMessage message = new SMSMessage();
                    message.To = NotificationSubscriptionObj.SubscriptionTarget;

                    // Get template text
                    NotificationTemplateTextInfo templateText = NotificationTemplateTextInfoProvider.GetNotificationTemplateTextInfo(NotificationGatewayObj.GatewayID, NotificationSubscriptionObj.SubscriptionTemplateID);
                    if (templateText != null)
                    {
                        if (Resolver != null)
                        {
                            // Resolve SMS text if Resolver is present
                            message.Text = Resolver.ResolveMacros(templateText.TemplatePlainText);
                        }
                        else
                        {
                            message.Text = templateText.TemplatePlainText;
                        }
                    }

                    // Create new SMS provider
                    SMSProvider provider = new SMSProvider();
                    // Authenticate
                    provider.Authenticate();
                    if (provider.Authenticated)
                    {
                        // Send message if authenticated
                        provider.SendSMS(message);
                        if (!provider.MessageSended)
                        {
                            // Log sending errror
                            EventLogProvider eventLog = new EventLogProvider();
                            eventLog.LogEvent("SMSNotificationGateway", "EXCEPTION", new Exception("Send error: " + provider.MessageSendError));
                        }
                    }
                    else
                    {
                        // Log authentication errror
                        EventLogProvider eventLog = new EventLogProvider();
                        eventLog.LogEvent("SMSNotificationGateway", "EXCEPTION", new Exception("Authentication error: " + provider.AthentificationError));
                    }
                }
            }
            catch (Exception ex)
            {
                try
                {
                    // Log the event
                    EventLogProvider eventLog = new EventLogProvider();
                    eventLog.LogEvent("SMSNotificationGateway", "EXCEPTION", ex);
                }
                catch
                {
                    // Unable to log the event
                }
            }
        }

        #endregion
    }
}
